<?php
defined('BASEPATH') OR exit('No direct script access allowed');
$addpmtr = "?outletid=".$this->input->get("outletid")."&fromdate=".$fromdate."&todate=".$todate;
$previousstockdate = date('d-M-Y', strtotime('-1 day', strtotime($fromdate)));
?>
      <div class="main my-0">
        <div class="row mt-3 mx-0">
          <div class="col-md-6">
            <h3>Manage Outlet Stock Status</h3>
          </div>
          <div class="col-md-6 text-right">
		  <?php
		  if(decodeValue($this->input->get("outletid"))>0)
		  {
			 $outletid =  decodeValue($this->input->get("outletid"));
		  ?>
			<a href="account/<?php echo $mgmtname;?>/exportcsv/?<?php echo $_SERVER['QUERY_STRING'];?>" class="btn btn-info">Export CSV</a>
			<a href="account/<?php echo $mgmtname;?>/exportpdf/?<?php echo $_SERVER['QUERY_STRING'];?>" class="btn btn-info">Export PDF</a>
			<a href="account/<?php echo $mgmtname;?>/exportpdftypewise/?<?php echo $_SERVER['QUERY_STRING'];?>" class="btn btn-info">Export Type Wise PDF</a>
			<?php
		  }
			  ?>
          </div>
        </div>
        
        <div class="container_fluid mt-2 px-3">
		<form name="frmsearch" method="get" action="account/<?php echo $mgmtname;?>">
         <table class="webforms sttbl bg-light my-0 table-responsive-sm">
          <tr>
           <td class="pr-0" width="20%"><input type="text" name="search" size="20" value="<?php echo $this->input->get("search");?>" placeholder="search name,barcode "></td>
          
          
          <td class="pr-0" width="20%">
		<select name="outletid" id="outletid" >
		  <option value="">Select Outlet</option>
						<?php
						if(is_array($outletlist) && count(array_filter($outletlist))>0)
						{

							foreach($outletlist as $outletrow)
							{
								$sel_outlet="";
								if(decodeValue($this->input->get("outletid"))==$outletrow->fld_id)
								{
									$sel_outlet = 'selected="selected"';
								}				
									?>
											<option value="<?php echo encodeValue($outletrow->fld_id);?>" <?php echo $sel_outlet;?>><?php echo $outletrow->fld_name;?></option>
									<?php
								
							}
						}
						?> 
		  </select>
		  </td>
           <td class="pr-0" width="20%"><input type="text" name="fromdate" id="fromdate" value="<?php echo $fromdate;?>"   placeholder="From Date" class="datepicker" /></td>
           <td class="pr-0" width="20%"><input type="text" name="todate" id="todate"  value="<?php echo $todate;?>" placeholder="To Date" class="datepicker"/></td>
           <td>
           	<button class="btn btn-dark pt-0 pb-1 px-2">Go</button>
           </td>
          </tr>
</tr>
		   <tr>
		<td width="20%">
		  <select name="type" id="type" class="js-example-basic-single">
		  <option value="">All Type</option>
						<?php
							
							foreach(arrProductType() as $ptkey => $ptval)
							{
								$sel_pt ="";
								if($this->input->get("type")==$ptkey)
								{
									$sel_pt = 'selected="selected"';
								}				
									?>
											<option value="<?php echo $ptkey;?>" <?php echo $sel_pt;?>><?php echo $ptval;?></option>
									<?php
								
							}
						
						?> 
		  </select>
		  </td>
          <td class="pr-0" width="20%">
		<select name="catid" id="catid" class="js-example-basic-single" >
		  <option value="">All Category</option>
						<?php
						if(is_array($catlist) && count(array_filter($catlist))>0)
						{

							foreach($catlist as $mcatrow)
							{
								$sel_mcat ="";
								if(decodeValue($this->input->get("catid"))==$mcatrow->fld_id)
								{
									$sel_mcat = 'selected="selected"';
								}				
									?>
											<option value="<?php echo encodeValue($mcatrow->fld_id);?>" <?php echo $sel_mcat;?>><?php echo $mcatrow->fld_name;?></option>
									<?php
								
							}
						}
						?> 
		  </select>
		  </td>

         <td class="pr-0" width="20%">
		<select name="brandid" id="brandid" class="js-example-basic-single" >
		  <option value="">All Brand</option>
						<?php
						if(is_array($brandlist) && count(array_filter($brandlist))>0)
						{
							foreach($brandlist as $brandrow)
							{
								$sel_brand ="";
								if(decodeValue($this->input->get("brandid"))==$brandrow->fld_id)
								{
									$sel_brand = 'selected="selected"';
								}				
									?>
											<option value="<?php echo encodeValue($brandrow->fld_id);?>" <?php echo $sel_brand;?>><?php echo $brandrow->fld_name;?></option>
									<?php
								
							}
						}
						?> 
		  </select>
		  </td>
		   <td colspan="2">
           &nbsp;
           </td>
          </tr>
         </table>
       </form>
         <?php
			if($this->session->flashdata("message")!="" && $this->session->flashdata("alerttype")!="")
			{
         ?>
         <div class="text-center my-4">
			 <span class="alert <?php echo $this->session->flashdata("alerttype");?>"><?php echo $this->session->flashdata("message");?></span>
         </div>
         <?php
			}
         ?>
         
         <table class="table mt-2 table-responsive-sm">
		 <form name="frmlisting" id="frmlisting" action="<?php echo base_url()."account/".$mgmtname;?>" method="post" onsubmit=" return checkboxvalidate();">
                <thead>
                	<tr>
                    	<th width="5%">SRNo.</th>                    	
                    	<th width="15%">Item</th>
						<th width="10%">Stock On <?php echo $previousstockdate;?></th>
                    	<th width="15%"  class="text-center">Stock IN</th>
                    	<th width="10%"  class="text-center">Stock OUT</th>                       
                        <th width="10%" class="text-right">Stock In Hand</th>
                    </tr>
                    </thead>
                    <tbody>
										<?php
					if(is_array($results) && count(array_filter($results))>0)
					{
						$rowindex = 0;
						$instock = 0;
						foreach($results as $row)
						{
							$rowindex++;
							$minstockvalue = minstockStatus($row['minstockvalue'],$row['instock']);

					?>
                    <tr>
                    	<td class="text-center"><?php echo $rowindex;?>.</td>
                    	<td><a href="account/orders/product/<?php echo encodeValue($row['id']).''. $addpmtr;?>"><?php echo $row['name'];?></a></td>
						<td  class="text-center"><?php echo round($row['previousstock'],2);?></td>
						<td  class="text-center"><?php echo round($row['incoming'],2);?></td>
                    	<td  class="text-center"><?php echo round($row['outgoing'],2);?></td>               
                    	              
                      
						<td class="text-right "> <span class="btn btn-<?php echo arrOSColor()[$minstockvalue];?> "><strong><?php echo $row['instock'];?></strong></span> </td>
                    </tr>
                    <?php
						}
							
					}
					else
					{
						if($this->input->get("outletid")=="")
						{
						?>
						<tr><td colspan="9" style="text-align:center">Please select outlet for stock status</td></tr>
						<?php

						}
						else
						{
                    ?>
                    <tr><td colspan="9" style="text-align:center">Record not found!</td></tr>
                    <?php
						}
					}
                    ?>
                    
                    
                    </tbody>
                </table>
                 
	         <div class="clearfix"></div>
          
        </div>
        <div id="paginate" class="row">
			<?php echo $this->ajax_pagination->create_links(); ?>
        </div>
            
        </div>

